# frozen_string_literal: true

require 'creditsafe/base_model'
require 'creditsafe/models/main_activity'
require 'creditsafe/models/company_status'
require 'creditsafe/models/currency_value'
require 'creditsafe/models/credit_rating'

module Creditsafe
  module Models
    class CompanySummary < BaseModel
      attributes :business_name, :country, :company_number, :company_registration_number,
                 :main_activity, :company_status, :latest_shareholders_equity_figure, :credit_rating

      def self.build(json:)
        super.tap do |record|
          record.main_activity = MainActivity.build(json: json.fetch(:mainActivity, {}))
          record.company_status = CompanyStatus.build(json: json.fetch(:companyStatus, {}))
          record.latest_shareholders_equity_figure = CurrencyValue.build(
            json: json.fetch(:latestShareholdersEquityFigure, {})
          )
          record.credit_rating = CreditRating.build(json: json.fetch(:creditRating, {}))
        end
      end
    end
  end
end
