# frozen_string_literal: true

require 'creditsafe/base_model'
require 'creditsafe/models/report'

module Creditsafe
  module Models
    class CreditReport < BaseModel
      ENDPOINT = 'companies/:connect_id'

      attributes :report, :company_id, :user_id, :date_of_order, :language

      def self.for(company_id)
        url = format_url(ENDPOINT, connect_id: company_id.to_s.strip)

        result = get(url)

        build(json: result.body)
      rescue InvalidRequestError
        build(json: {})
      end

      def self.build(json:)
        super.tap do |record|
          record.report = Report.build(json: json[:report]) if json.key?(:report)
        end
      end
    end
  end
end
